@@ -1,5 +1,7 @@
 //! A type-safe representation of a bell.
 
+use std::fmt::{Debug, Display, Formatter};
+
 #[cfg(feature = "serde")]
 use serde_crate::{
     de::{Error, Visitor},
@@ -9,7 +11,8 @@ use serde_crate::{
 use crate::Stage;
 
 /// A lookup string of the bell names
-// - E, T stand for 11 and 12 and therefore feel out of place
+// Letters missing from the alphabet sequence
+// - E, T stand for 11 and 12
 // - I could be confused with 1
 // - O could be confused with 0 and Q
 // - X is not a valid bell name to avoid confusion with 'x' as place notation
@@ -17,7 +20,7 @@ const BELL_NAMES: &str = "1234567890ETABCDFGHJKLMNPQRSUVWYZ";
 
 /// A type-safe representation of a 'bell', which adds things like conversions to and from
 /// commonly-used bell names.
-#[derive(Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
+#[derive(Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
 pub struct Bell {
     /// A zero-indexed number representing the `Bell`.  I.e the treble is always
     /// `Bell { index: 0 }`, and the 12th is `Bell { index: 11 }` but would be
@@ -103,15 +106,16 @@ impl Bell {
     /// use bellframe::{Bell, Stage};
     ///
     /// // The **5** is the 'tenor' when ringing Doubles
-    /// assert_eq!(Bell::tenor(Stage::DOUBLES)?, Bell::from_number(5)?);
+    /// assert_eq!(Bell::tenor(Stage::DOUBLES), Bell::from_number(5)?);
     /// // The 12 is the tenor on maximus
-    /// assert_eq!(Bell::tenor(Stage::MAXIMUS)?, Bell::from_number(12)?);
+    /// assert_eq!(Bell::tenor(Stage::MAXIMUS), Bell::from_number(12)?);
     /// # Some(())
     /// # }
     /// # fn main() { test().unwrap() }
     /// ```
-    pub fn tenor(stage: Stage) -> Option<Bell> {
-        Self::from_number(stage.as_usize())
+    pub fn tenor(stage: Stage) -> Bell {
+        // Unwrapping here is safe because `Stage.num_bells()` can never be zero
+        Self::from_number(stage.num_bells()).unwrap()
     }
 
     /// A [`Bell`] representing the 'treble' on any stage.  Equivalent to
@@ -150,7 +154,7 @@ impl Bell {
     /// # }
     /// # fn main() { test().unwrap() }
     /// ```
-    pub fn to_char(&self) -> Option<char> {
+    pub fn to_char(self) -> Option<char> {
         BELL_NAMES.as_bytes().get(self.index).map(|x| *x as char)
     }
 
@@ -222,7 +226,7 @@ impl Bell {
     /// # }
     /// # fn main() { test().unwrap() }
     /// ```
-    pub fn name(&self) -> String {
+    pub fn name(self) -> String {
         match self.to_char() {
             None => format!("<{}>", self.number()),
             Some(c) => c.to_string(),
@@ -230,12 +234,54 @@ impl Bell {
     }
 }
 
-impl std::fmt::Display for Bell {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+impl Debug for Bell {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "Bell({})", self)
+    }
+}
+
+impl Display for Bell {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "{}", self.name())
     }
 }
 
+impl std::ops::Add<usize> for Bell {
+    type Output = Bell;
+
+    fn add(self, rhs: usize) -> Self::Output {
+        Self {
+            index: self.index + rhs,
+        }
+    }
+}
+
+impl std::ops::AddAssign<usize> for Bell {
+    fn add_assign(&mut self, rhs: usize) {
+        self.index += rhs;
+    }
+}
+
+impl std::ops::Sub<usize> for Bell {
+    type Output = Bell;
+
+    fn sub(self, rhs: usize) -> Self::Output {
+        Self {
+            index: self.index - rhs,
+        }
+    }
+}
+
+impl std::ops::SubAssign<usize> for Bell {
+    fn sub_assign(&mut self, rhs: usize) {
+        self.index -= rhs;
+    }
+}
+
+///////////
+// SERDE //
+///////////
+
 #[cfg(feature = "serde")]
 struct BellVisitor;
 
@@ -300,14 +346,14 @@ impl<'de> Visitor<'de> for BellVisitor {
     where
         E: Error,
     {
-        Bell::from_number(v as usize).ok_or(E::custom("can't have Bell #0"))
+        Bell::from_number(v as usize).ok_or_else(|| E::custom("can't have Bell #0"))
     }
 
     fn visit_char<E>(self, v: char) -> Result<Self::Value, E>
     where
         E: Error,
     {
-        Bell::from_name(v).ok_or(E::custom(format!("'{}' is not a bell name", v)))
+        Bell::from_name(v).ok_or_else(|| E::custom(format!("'{}' is not a bell name", v)))
     }
 
     fn visit_str<E>(self, v: &str) -> Result<Self::Value, E>
@@ -321,7 +367,7 @@ impl<'de> Visitor<'de> for BellVisitor {
         v.chars()
             .next()
             .and_then(Bell::from_name)
-            .ok_or(E::custom(format!("'{}' is not a bell name", v)))
+            .ok_or_else(|| E::custom(format!("'{}' is not a bell name", v)))
     }
 }
 
