@@ -15,6 +15,7 @@ pub mod place_not;
 pub mod row;
 mod stage;
 mod stroke;
+mod truth;
 mod utils;
 
 // Re-export useful data types into the top level of the crate
@@ -29,6 +30,7 @@ pub use place_not::{PlaceNot, PnBlock};
 pub use row::{same_stage_vec::SameStageVec, InvalidRowError, Row, RowBuf};
 pub use stage::{IncompatibleStages, Stage};
 pub use stroke::Stroke;
+pub use truth::Truth;
 pub use utils::run_len;
 
 #[cfg(feature = "cc_lib_gen")]
